@@ -13,6 +13,8 @@
 
 #include "common/common_pch.h"
 
+#include <QDateTime>
+
 #include "common/command_line.h"
 #include "common/date_time.h"
 #include "common/debugging.h"
@@ -123,7 +125,7 @@ mxmsg(unsigned int level,
 
   std::string prefix;
   if (s_timestamped_messages) {
-    prefix += mtx::date_time::format_time_point(std::chrono::system_clock::now(), "%Y-%m-%d %H:%M:%S.%f ", mtx::date_time::epoch_timezone_e::local);
+    prefix += mtx::date_time::format(QDateTime::currentDateTime(), "%Y-%m-%d %H:%M:%S.%f ");
   }
   if (s_memory_usage_in_messages) {
     prefix += fmt::format("{0} kB ", mtx::sys::get_memory_usage() / 1024);
@@ -198,45 +200,46 @@ void
 mxerror(std::string const &error) {
   if (s_mxmsg_error_handler)
     s_mxmsg_error_handler(MXMSG_ERROR, error);
+  mxexit(2);
 }
 
 void
 mxinfo_fn(const std::string &file_name,
           const std::string &info) {
-  mxinfo(fmt::format(Y("'{0}': {1}"), file_name, info));
+  mxinfo(fmt::format(FY("'{0}': {1}"), file_name, info));
 }
 
 void
 mxinfo_tid(const std::string &file_name,
            int64_t track_id,
            const std::string &info) {
-  mxinfo(fmt::format(Y("'{0}' track {1}: {2}"), file_name, track_id, info));
+  mxinfo(fmt::format(FY("'{0}' track {1}: {2}"), file_name, track_id, info));
 }
 
 void
 mxwarn_fn(const std::string &file_name,
           const std::string &warning) {
-  mxwarn(fmt::format(Y("'{0}': {1}"), file_name, warning));
+  mxwarn(fmt::format(FY("'{0}': {1}"), file_name, warning));
 }
 
 void
 mxwarn_tid(const std::string &file_name,
            int64_t track_id,
            const std::string &warning) {
-  mxwarn(fmt::format(Y("'{0}' track {1}: {2}"), file_name, track_id, warning));
+  mxwarn(fmt::format(FY("'{0}' track {1}: {2}"), file_name, track_id, warning));
 }
 
 void
 mxerror_fn(const std::string &file_name,
            const std::string &error) {
-  mxerror(fmt::format(Y("'{0}': {1}"), file_name, error));
+  mxerror(fmt::format(FY("'{0}': {1}"), file_name, error));
 }
 
 void
 mxerror_tid(const std::string &file_name,
             int64_t track_id,
             const std::string &error) {
-  mxerror(fmt::format(Y("'{0}' track {1}: {2}"), file_name, track_id, error));
+  mxerror(fmt::format(FY("'{0}' track {1}: {2}"), file_name, track_id, error));
 }
 
 void
