@@ -14,6 +14,7 @@
 #include "common/common_pch.h"
 
 #include <QRegularExpression>
+#include <QTimeZone>
 
 #include <ebml/EbmlVersion.h>
 #include <matroska/KaxVersion.h>
@@ -26,7 +27,7 @@
 #include "common/strings/parsing.h"
 #include "common/version.h"
 
-constexpr auto VERSIONNAME = "All I Know";
+constexpr auto VERSIONNAME = "And the Melody Still Lingers On (Night in Tunisia)";
 
 version_number_t::version_number_t(const std::string &s)
   : valid{}
@@ -207,7 +208,7 @@ get_default_segment_info_data(std::string const &application) {
   } else {
     data.muxing_app   = "no_variable_data";
     data.writing_app  = "no_variable_data";
-    data.writing_date = QDateTime::fromSecsSinceEpoch(0, Qt::UTC);
+    data.writing_date = QDateTime::fromSecsSinceEpoch(0, QTimeZone::utc());
   }
 
   return data;
